classdef eCube_Mesh < eMesh
    %eCube_Mesh CUbe versio of grid
    %   Constructor:  sampling [mm], mesh_name
    
    properties
        % ingerited
%         mesh_name         % mesh name e.g. cartesian
%         size_mm='none'    % (xmin xmax itd) like bounding box
%         sampling          % dimension [x,y,z] sampling      
         cube_point_list_and_vertices='none' % element number and coordinates of vertices belongs to this object
         size_discrete_xyz % discrete size of volume in each direction
         x_mm_centers      % centers of discrete elements in milimeters
         y_mm_centers      % centers of discrete elements in milimeters
         z_mm_centers      % centers of discrete elements in milimeters
         X_disp='none'      % each describes centers of discret points (generated wit meshgrid)
         Y_disp='none'             
         Z_disp='none'
         
         x_mm_cube_corners % coordinates of all the grid points of cube corner in milimeters
         y_mm_cube_corners
         z_mm_cube_corners
    end
    
    methods (Access='public')
          %   Constructor:  sampling [mm], mesh_name
          function this = eCube_Mesh(varargin)
          if nargin > 0 ; % no input arguments
          if isa(varargin{1},'eCube_Mesh')
            this = varargin{1}; % copy constructor
            display 'Copy constructor eCube_Mesh'
            return;                     
          else
             switch(nargin)                                  
              
                case 2,                                
                this.sampling=varargin{1};                
                this.mesh_name=varargin{2};                                                                            
                                            
                case 3,                                
                this.sampling=varargin{1};                
                this.mesh_name=varargin{2};      
                this.size_mm=varargin{3};      
                
                 otherwise,
                     error('Too less or too much input elements');
             end % switch
          end % if
          end % if
          end % constructor
        
        set_size(varargin)
        % size of mesh
        % input: bounding_box_xyz
          
        show_elements(varargin)
        % input: point list vector
        % output: plot given elements
        
        show_neighbours(varargin)
        % input: point list of one element
        % output: plot neighbours of given element linear indicies
        
        [sampling_struct]=get_sampling(none);
        % return data structure contains sampling in all coordinates
        
        [pointlist cube_point_list_and_vertices_of_meshed_object] = set_geometry_object( varargin );
        % set object to mesh (object inherits geometry primitive)        
        
        [status]=do_mesh(nth);
        % meshing object (if object is set)
        
        [point_list_index]=sub2index(subscript)
        % subscript dimension coordinates of discrete element e.g. xyz
        % return point list value
        
        [point_list_index]=index2sub(subscript)
        % subscript dimension coordinates of discrete element e.g. xyz
        % return point list value
        
        [neighbour_dim_coordinate_vector ] = get_neighbours_coordinates(dimension_coordinates);
        % dimension_coordinates dimension coordinates e.g. x y z
        % returns vector of mdimension coordinates of neighbours
        
        [neighbour_point_list_vector xyz_matrix_indicies] = get_neighbours(varargin);
        % point_list_value point list value of discret element
        % returns neighbour_point_list_vector vector of point list values
        % (6 elements)
        % and xyz_matrix indicies of neighbours (6x3)
        
        [name]=get_name(none);
        % return name of discretization grid object
        
        convert(name);
        % convert data from set coordinate system to other
        % name-name of coordinate system which current system will be
        % converted to
        
        set_scale(scale_value_vector)
        % set multiplication value for each coordinate e.g. set_scale(2) ->
        % sampling.x=2*sampling.x etc.
        
        scale_value=get_scale(none)
        % return current scale value 
        
        show_grid(varargin)
        % show mesh grid
        
        [point_list_of_volume]=get_point_list_of_volume(varargin)
        % input: volume size in milimeters (size must be less or equal to current mesh size)
        % e.g. [x_mm_min x_mm_max y_mm_min y_mm_max z_mm_min z_mm_max]
        % you can use it after at least one object have been meshed
        % return point list of specific volume size
        
        [ neighbours ] = get_all_neighbours( varargin )
        % get all neihgbours from given vector
        % return vector with neighbours

    end
    
end

