function [X Y Z]=mpi_meshgrid(K,voxelsize)
% mpi_mesh - generates meshgrid 
%
% [X Y Z]=mesh_grid(K,voxelsize)
%
% K - matrix size
% voxelsize - cubic voxel size [mm]
%
% RETURNS:
% X Y Z  - 3D matrices with grid coordinates [mm] in right handed 
% cartesian coordinates system
%
% i,j,k subscripts of 3D matrix compose left handed cartesian
% coordinates system
% RIGHT HANDED COORDINATE SYSTEM is required for geometrical
% transformations (i,j,k) -> (y,x,z)
% squeeze(A(:,:,p)) -> (yx) with y down oriented
% squeeze(A(:,c,:)) -> (yz) with y down oriented
% squeeze(A(r,:,:)) -> (xz) with x down oriented
% all volume slices (2D images) should be flipped up-down


xv = -(K-1)*voxelsize/2: voxelsize: (K-1)*voxelsize/2;  % X with plane
yv = -(K-1)*voxelsize/2: voxelsize: (K-1)*voxelsize/2;  % Y with column
zv = -(K-1)*voxelsize/2: voxelsize: (K-1)*voxelsize/2;  % Z with row
[X Y Z]  = meshgrid(xv,yv,zv);  % [mm]


