function potential_maps=potential_iterative_mfile(varargin)
%function potential_maps=potential_iterative_mex(maxiter, deltammin)
% potential_iterative_mex - calculates potential distribution in 3D 
%
% potential_maps = EF.potential_iterative(maxiter,deltamin)
%
% input:
%       maxiter=varargin{2};  number of max iteration of algorithm
%
%       deltamin=varargin{3};
%       e.g. 1e-14;  % almost the precision of double precision float e-16      
%
% the Ampere law in differential form -> finite difference formula
% Iterative algorithm
% apply finite difference formula for all voxels 
% and repeat this many steps until the potential distribution stabilizes
%

this=varargin{1};
maxiter=varargin{2};
deltamin=varargin{3};
%e.g. deltamin = 1e-14;  % almost the precision of double precision float e-16

point_list=this.point_list;         % values of point list
num_uf_point_list=length(point_list);

permittivity=this.permittivity;
boundary=this.boundary;             % boundary values for each point list '-1' means potential must be compute

iidx_neighbours=this.neighbours_iidx;

potential_maps=zeros(size(this.potential_maps));
potential_maps(:)=this.potential_maps(:); % map where computed values will be insert

previous_potential_map=zeros(size(this.potential_maps));
% iterative algorithm
% apply finite difference formula for all voxels 
% and repeat this many steps until the potential distribution stabilizes
for it=1:maxiter  
    previous_potential_map(:)=potential_maps(:);
    for num_pl=1:num_uf_point_list

        if boundary(num_pl)==-1
        % else dont't compute potential, leave as is
            iidx_vector=iidx_neighbours(num_pl,:);
            current_perm= permittivity(num_pl);

            % index of elements to remove
            elems_to_remove=iidx_vector<0;

            % remove
            iidx_vector(elems_to_remove)=[];

            % get neighbours permittivity
            perm_elments_weights = permittivity(iidx_vector);
            %perm_elments_weights = cell2mat(perm_elments_weights);
            perm_elments = (perm_elments_weights + current_perm);
            %perm_weight=sum(perm_elments_weights)+ current_perm*numel(iidx_vector);
            perm_weight=sum([perm_elments_weights' current_perm*numel(iidx_vector)]);
            % get neighbours potential(index of neighbour nodes, potential from successive electrodes)
            potential_elements = potential_maps(iidx_vector,:);                                            
           
            % matrix multiplication (in one step we compute potetial for all electrodes):
            potential_in_point=potential_elements'*perm_elments;
            
            % divide each element in vector
            potential_in_point=potential_in_point./perm_weight;
            potential_maps(num_pl,:)=potential_in_point(:);
        end
        
    end
    % stopping criterion uses square norm
    delta = norm(max(max(abs((potential_maps(:)-previous_potential_map(:))))),2);
    
    if delta<deltamin
        disp('stopping criterion: calculation precision reached\n')
		return
    end
    
    % progress bar in console mode
   	if mod(it,10)==0
        it
       delta
    end
end

this.potential_maps=potential_maps;

disp('stopping criterion: maximum iteration number reached\n')

