classdef eElement < handle
    % Describes basic ECTSim structural element use to build
    % numerical object (FEM object) which represents real objects
    
    properties (SetAccess='public')        
        name                % name of the element e.g. electrode, plastic rod, etc. 
        element_id          % unique identificator of the element
        geometry            % object of class GeometryPrimitive
        material            % object of class Material        
        boundary_value      % e.g. potential (vector)
        point_list          % list of points of current object        
        point_list_and_vertices     % list of points and vertices coordinates in cartesian coordinate system                            
        is_meshed           % flag is set when object was meshed
        is_boundary='none'  % is set when object describes boundary condition        
        potential='none'    % potential value       
        graphics            % eGraphics object is use to get praphics params use to display
    end
    
    methods (Access='public')
        
        function this=eElement(varargin)            
        % constructor: name, element_id
        % example:
        % name='insulator'
        % element_id=1;
        % FEM_Element(name,element_id)   
        % or you can use wizard
        % FEM_Element('wizard')
        
            if nargin > 0 ; % number input arguments
              if isa(varargin{1},'eElement')
                this = varargin{1}; % copy constructor
                display 'Copy constructor eElement'
                return;                     
              else                                           
                   switch(nargin)
                       case 1,
                           if(strcmp(varargin{1},'wizard'))                               
                               name=input('Object name:', 's');
                               
                               if isempty(name)
                                    error('empty value')
                               end                                                                         
                               
                               this.name=name;
                               
                               
                               element_id=input('Object id:', 's');
                               
                               if isempty(name)
                                    error('empty value')
                               end                                                                         
                               element_id=str2double(element_id);
                               
                               this.name=name;
                               this.element_id=element_id;
                               display('Remember to set Material and Geometry objects!');
                           end
                           
                       case 2,  
                        
                          this.name=varargin{1};
                          this.element_id=varargin{2};

                          
                    otherwise,
                             error('Too less or too much input elements');
                   end % switch   
                   
                   this.graphics=eGraphics();
              end
            end
            end%constructor        
            
           function set_material_obj(varargin)
            % set material object
                fe_obj=varargin{1};
                mat_obj=varargin{2};
                if (isa(varargin{2},'eMaterial'))
                    fe_obj.material=mat_obj;
                else
                    error('This is not eMaterial Object.')
                end
            end
            
           function set_geometry_obj(varargin)
           % set geometry primitive
                fe_obj=varargin{1};
                geo_obj=varargin{2};
                if (isa(varargin{2},'eGeometric_Primitive'))
                    fe_obj.geometry=geo_obj;
                else
                    error('This is not eGeometric_Primitive.')
                end
           end
           
           function set_boundary(varargin)
           % set geometry primitive
                fe_obj=varargin{1};
                boundary_val=varargin{2};
                
                fe_obj.potential=boundary_val;
                fe_obj.is_boundary=1;
           end
            
           function set_graphics(varargin)
           % set geometry primitive
                this=varargin{1};
                gr_obj=varargin{2};
                if (isa(varargin{2},'eGraphics'))
                    this.graphics=gr_obj;
                else
                    error('This is not eGraphics object.')
                end
            end
        % set point list using given Mesh
        % input Mesh
        [pointlist point_list_and_vertices]=assign_mesh_points(varargin);
        
        % display sketch of the object
        % input color structure color.r=0.5 color.g= color.b= 
        [h_plot]=sketch(varargin);        
        
        % 3d or 2d view of object
        mesh_view(varargin);                
                
        %return point list data 
        [point_list]=get_point_list(none);
        
        % return 'true'(string data) if object was meshed otherwise 'false'(string data)
        [bool]=meshed_state(none);
        
        % return unique id of the element
        [id]=get_element_id(none);
        
        % return element name
        [name]=get_element_name(none);
        
        % return matrix where value is set to '1' where object exist
        [mtrx]=get_matrix(none)
               
    end %methods
    
end

