function C=compute_C(varargin)
% compute capacitance for each electrode
% input: computation mode ('correction', 'without_correction')
% output capacitance (the same value is set in object class)

this=varargin{1};

switch(nargin)                                  
    case 1,
        point_list=this.point_list;
    case 2, 
        point_list=varargin{2};
    case 3
        point_list=varargin{2};
        mode=varargin{3};
        
 otherwise,
 error('Too less or too much input elements');
end % switch

S_map_size=size(this.S_map);
num_of_sens_maps=S_map_size(1);


point_list_size=numel(point_list);

%alloc memory
this.S_matrix=zeros(num_of_sens_maps,point_list_size);

% get Sensitivity
for i=1:num_of_sens_maps
    %get one sensitivity map 
    S_3d(:,:,:)=this.S_map(i,:,:,:);
    
    % select from single sensitivity map only specific pionts
    % (usualy these where potential was computed)
    S_selected_points=S_3d(point_list);
    
    % reshape 3d matrix to single vector
    this.S_matrix(i,:)=S_selected_points(:);
end

if strcmp(mode,'without_correction')
    % get Permittivity
    permittivity=this.permittivity_3d_matrix(point_list);

    permittivity=permittivity.*this.vacuum_permittivity;

    this.C=this.S_matrix*permittivity';

    C=this.C;
elseif strcmp(mode,'correction')
    
    if strcmp(this.corr,'none')
        sensitivity_correction_index=this.index_which_sensitivity_maps_to_correct;
        this.corr = this.geometric_correction(sensitivity_correction_index,this.S_matrix);     
    end
    
    S_matrix=this.S_matrix;
    [r c]=size(S_matrix);
    for i=1:r
        S_matrix(i,:)=S_matrix(i,:)*this.corr(i);
    end
    this.S_matrix=S_matrix;
    % get Permittivity
    permittivity=this.permittivity_3d_matrix(point_list);

    permittivity=permittivity.*this.vacuum_permittivity;

    this.C=this.S_matrix*permittivity';

    C=this.C;
end
    
end

