function  [return_vals]=calculate_model(varargin)
% calculates boundary and permittivity maps
%
% object variable boundary_permittivity_neighbours is set
% boundary_permittivity_neighbours contains: 
% pointlist 
% permittivity 
% start potential of each discrete point 
% neighbours pidx 
% neighbours iidx
% potential boundaries
% 
% input:
% change_value_object_name   name of the object that will be changing
% values e.g. 'electrode'
% potential_on   values of the object e.g. electrode when potential is on
% potential_off  values of the object e.g. electrode when potential is off
% potential__others_start_vals   start potential values of no boundary objects
%
% output:
% return_vals=[matrix_mesh_size boundary_permittivity_neighbours all_boundary_change_val_object_iidx_and_pidx separate_change_val_object_iidx_pidx];
%

this=varargin{1};
change_value_object_name=varargin{2};
potential_on=varargin{3};
potential_off=varargin{4};
potential_others_start_vals=varargin{5};

mesh=this.mesh;
% e.g.: electrodes changing his potential value 

linear_indicies=this.all_elements.get_linear_indicies();

%alloc
this.boundary_permittivity_neighbours=zeros([length(linear_indicies) 3]);

%fill with '-1'
this.boundary_permittivity_neighbours(:,:)=-1;

this.boundary_permittivity_neighbours(:,1)=linear_indicies(:);

%alloc
permittivity_tmp=ones(length(linear_indicies),1).*(-1);

tmp=mesh.get_neighbours(1);
neighbours_tmp=ones(length(linear_indicies),length(tmp)).*(-1);
neighbours_iidx_tmp=ones(length(linear_indicies),length(tmp)).*(-1);
%point_list_model=cell2mat(this.boundary_permittivity_neighbours(:,1));
point_list_model=linear_indicies;

model_elements=this.all_elements.get_all();

len=length(model_elements);

% Set with object which boundry values changing
set_bundary_val_change=eSet('boundary_val_change');

p=1;
display 'calculate model'
for i=1:len
    point_list=model_elements(i).point_list;
    potential=model_elements(i).potential;
    permittivity=model_elements(i).material.material_parameter_value_vector(1);
    boundary_set=model_elements(i).is_boundary;
    object_name=model_elements(i).name;
    %id=model_elements(i).element_id;
    
    % add to Set with object which boundry values changing
    if strcmp(object_name,change_value_object_name)
        set_bundary_val_change.add_element(model_elements(i));
        pidx_of_object=model_elements(i).point_list;
        
        iidx_of_object=zeros([length(pidx_of_object) 1]);        
        for k=1:length(pidx_of_object)
            iidx_of_object(k)=find(point_list_model==pidx_of_object(k));
        end
        
        tmp=zeros([length(iidx_of_object) 2]);                
        
        iidx_of_object=iidx_of_object';
        tmp(:,1)=iidx_of_object(:);
        
        %pidx_of_object=pidx_of_object';
        tmp(:,2)=pidx_of_object(:);

        separate_change_val_object_iidx_pidx(:,:,p)={tmp};
        % change value object
        p=p+1;
    end
    
    len_pl=length(point_list);
    for k=1:len_pl
        point_indicies=point_list(k);
        
        indicies=find(point_list_model==point_indicies);
        
        %point_list permittivity potential
        model_point_perm=this.boundary_permittivity_neighbours(indicies,2);
                
        model_point_potential=this.boundary_permittivity_neighbours(indicies,3);        
                
        if model_point_perm==-1
%             display('perm in')
            %this.boundary_permittivity_neighbours(indicies,2)={permittivity};
            permittivity_tmp(indicies)=permittivity;
            this.boundary_permittivity_neighbours(indicies,2)=permittivity;
        else
            res=(model_point_perm+permittivity)/2;
            this.boundary_permittivity_neighbours(indicies,2)=res;
        end
        
        if strcmp(boundary_set,'none')
            %do nth
        else
%             display('boundary in')            
            if model_point_potential==-1
                this.boundary_permittivity_neighbours(indicies,3)=potential;
            else
                potentials=[model_point_potential potential];
                res=max(potentials);
                this.boundary_permittivity_neighbours(indicies,3)=res;            
            end
                         
        end
                % get neighbours
        %neighbours=[];
        neighbours=mesh.get_neighbours(point_indicies);
        % if point list doesn't exist value '-1' is return
 
        tmp_neihgbours=neighbours;
        neighbours_tmp(indicies,:)=tmp_neihgbours(:);
        %this.boundary_permittivity_neighbours(indicies,4)={tmp_neihgbours};
        
        indicies_1=find(point_list_model==neighbours(1));
        if isempty(indicies_1)
            indicies_1=-1;
        end
        indicies_2=find(point_list_model==neighbours(2));
        if isempty(indicies_2)
            indicies_2=-1;
        end
        indicies_3=find(point_list_model==neighbours(3));
        if isempty(indicies_3)
            indicies_3=-1;
        end
        indicies_4=find(point_list_model==neighbours(4));
        if isempty(indicies_4)
            indicies_4=-1;
        end
        indicies_5=find(point_list_model==neighbours(5));
        if isempty(indicies_5)
            indicies_5=-1;
        end
        indicies_6=find(point_list_model==neighbours(6));
        if isempty(indicies_6)
            indicies_6=-1;
        end
        
        indicies_f=[indicies_1 indicies_2 indicies_3 indicies_4 indicies_5 indicies_6];
        
        tmp_indicies=indicies_f;
        
        neighbours_iidx_tmp(indicies,:)=tmp_indicies(:); 
                
    end
    
end


%cpy to output array
this.boundary_permittivity_neighbours(:,2)=permittivity_tmp(:);

%cell_tmp_neighbours=num2cell(neighbours_tmp,2);
sz_neighbours_pidx=size(neighbours_tmp);
this.neighbours_pidx=zeros(sz_neighbours_pidx);
this.neighbours_pidx=neighbours_tmp;



sz_neighbours_iidx=size(neighbours_iidx_tmp);
this.neighbours_iidx=zeros(sz_neighbours_iidx);
this.neighbours_iidx=neighbours_iidx_tmp;

% mesh size use to display
matrix_mesh_size=this.mesh.size_discrete_xyz;

%changing values boundary object
boundary_change_val_object_pidx=set_bundary_val_change.get_linear_indicies();
for j=1:length(boundary_change_val_object_pidx)
    boundary_change_val_object_iidx(j)=find(point_list_model==boundary_change_val_object_pidx(j));
end

%alloc memory
all_boundary_change_val_object_iidx_and_pidx=zeros([length(boundary_change_val_object_pidx) 2]);

% first col iidx second pidx
all_boundary_change_val_object_iidx_and_pidx(:,1)=boundary_change_val_object_iidx(:);
all_boundary_change_val_object_iidx_and_pidx(:,2)=boundary_change_val_object_pidx(:);


%boundary_permittivity_neighbours=this.boundary_permittivity_neighbours;

% number of change value object
number_of_change_value_object=p-1;


%alloc
potential_maps=zeros(length(linear_indicies),number_of_change_value_object);

for m=1:number_of_change_value_object

    %alloc
    boundary_start=zeros(length(linear_indicies),1);
    boundary_start(:)=potential_others_start_vals;

    boundary_start(all_boundary_change_val_object_iidx_and_pidx(:,1))=potential_off;

    iidx_pidx_sep=separate_change_val_object_iidx_pidx(m);
    vals=iidx_pidx_sep{1};  
    boundary_start(vals(:,1))=potential_on;
    
    potential_maps(:,m)=boundary_start(:);
end

% for m=1:number_of_change_value_object
%     boundary_start=this.boundary_permittivity_neighbours(:,3);
% 
%     boundary_start(all_boundary_change_val_object_iidx_and_pidx(:,1))={potential_off};
% 
%     iidx_pidx_sep=separate_change_val_object_iidx_pidx(m);
%     vals=iidx_pidx_sep{1};
%     boundary_start(vals(:,1))={potential_on};
%     
%     potential_maps(:,m)=boundary_start(:);
% end

%alloc

 this.boundary_permittivity_neighbours=[this.boundary_permittivity_neighbours potential_maps];
 boundary_permittivity_neighbours=this.boundary_permittivity_neighbours;
 
 display 'end calculate model'
 
 return_vals={matrix_mesh_size boundary_permittivity_neighbours this.neighbours_pidx this.neighbours_iidx all_boundary_change_val_object_iidx_and_pidx separate_change_val_object_iidx_pidx};
 
