classdef eModel < handle
    %EMODEL Summary of this class goes here
    %   Detailed explanation goes here
    
    properties (SetAccess='public')
        mesh
        name         % model  name
        sensor       % Set sensor object
        phantom      % Set phantom object
        all_elements % this set should contains Set which contains all elements in model
        boundary_permittivity_neighbours % table contains pointlist permittivity and potential of each discrete point
        boundary_change_val_object_iidx_and_pidx
        separate_change_val_object_iidx_pidx
        neighbours_pidx
        neighbours_iidx
        
        permittivity  % permittivity points where calculate values length 
                      % coresponding to point_list_where_calculate
        point_list_where_calculate % only in this points calculation have been done
        boundary      % vector describes if in specific points are boundary values or not length 
                      % coresponding to point_list_where_calculate
        permittivity_matrix_3d % 3d permittivity matrix
        all_computed_values % all values which can be useful to make any computation
    end
    
    methods (Access='public')
        
        function this = eModel(varargin)
        % set name or type 'wizard':
        % eModel('name')
        % or
        % eModel('wizard')
        
          if nargin > 0 ; % no input arguments
          if isa(varargin{1},'eModel')
            this = varargin{1}; % copy constructor
            display 'copy constructor eModel'
            return;                     
          else
               switch(nargin)
                   
                case 1,   
                
                if(strcmp(varargin{1},'wizard'))
                    
                    this.wizard(); %set eModel from input                    

                else
                    
                    this.name=varargin{1};
                    
                end 
                
                this.all_elements=eSet('all_elements');
                
               otherwise,
                         error('Too less or too much input elements');
               end % switch
          end
          end
        
        end % constructor
                
        [bounding_box_xyz]=get_bounding_box(varargin);
        % return bounding values xmin, xmax etc
        % [xmin xmax ; ymin ymax ; zmin zmax ]
        
        add_phantom(varargin)                
        % input: Set which contains Phantom
        
        add_sensor(varargin)
        % input: Set which contains Sensor
        
        [return_vals]=calculate_model(varargin)
        % calculates boundary and permittivity maps
        
        mesh_view(varargin)
        % plots mesh (discrete view of object)
        
        [permittivity permittivity_matrix_3d]=change_permittivity_value_in_points(varargin)
        % use only if know why using this function
        % Use this function if you want to change permittivity values
        % without recalculate whole model
        % input: point list 
        %        value
        % output permittivity is set for this object
        
        [iidx_indicies]=find_neighbours_iidx(varargin)
        % find neighbours iidx
        % input vector with neighbours pidx
        % output vector with iidx
        
        [point_list_invp size_discrete_xyz]=getlinear_points_invp(varargin)
        % return point_list of given object in when size is set
        % input object name
        %       set size
        % output linear index 
        %        size of discrete invp mesh in 3d
    end
    
end

