/*********************************************************************
 * potential_iterative_c.cpp
 *
 * This file computes potential values in 3 dimension using iterative 
 * algorithm.
 * 
 * Keep in mind:
 * <> Use 0-based indexing as always in C or C++
 * <> Indexing is column-based as in Matlab (not row-based as in C)
 * <> Use linear indexing.  [x*dimy+y] instead of [x][y]
 * 
 ********************************************************************/
#include <matrix.h>
#include <mex.h>   
#include <math.h>   
#include <iostream>

using namespace std;

#define PI (3.141592653589793)
        
void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{

//declare variables
    mxArray *xyz_vector_mx,
            *margin_vector_mx,
            *object_size_mx,
            *stts_mx;
      
    double  *xyz_vector,
            *margin_vector,
            *object_size,
            *stts,
            x,y,z,
            margin_x,margin_y,margin_z,
            r_max,r_min,
            x_centre,y_centre,
            z_high,z_low,
            a_start,a_stop,
            
            obj_r_highm,obj_r_lowm,
            obj_z_highm,obj_z_lowm,
            obj_a_startm,obj_a_stopm,
            R,TH;                        

//associate inputs
    xyz_vector_mx              = mxDuplicateArray(prhs[0]);
    margin_vector_mx           = mxDuplicateArray(prhs[1]);               
    object_size_mx             = mxDuplicateArray(prhs[2]); 
    
//associate outputs           
    stts_mx = plhs[0] = mxCreateDoubleMatrix(1, 1, mxREAL);   

//associate pointers
          
    xyz_vector    = mxGetPr(xyz_vector_mx);
    margin_vector = mxGetPr(margin_vector_mx);
    object_size = mxGetPr(object_size_mx);
    stts = mxGetPr(stts_mx);

//get specific input data
    
    x=xyz_vector[0];
    y=xyz_vector[1];
    z=xyz_vector[2];
    
    margin_x=margin_vector[0];
    margin_y=margin_vector[1];
    margin_z=margin_vector[2];
    
    r_max   =object_size[0];
    r_min   =object_size[1];
            
    x_centre=object_size[2];
    y_centre=object_size[3];
            
    z_high  =object_size[4]; 
    z_low   =object_size[5];
            
    a_start =object_size[6];
    a_stop  =object_size[7];
            
    
    obj_r_highm = r_max + margin_y;
    obj_r_lowm  = r_min - margin_y;
    
    R=sqrt(pow(abs(x-x_centre),2)+pow(abs(y-y_centre),2));
    
    // outside side
    if (R<= obj_r_highm && R >= obj_r_lowm){
        obj_z_highm=z_high+margin_x;
        obj_z_lowm=z_low-margin_x;
        if (obj_z_lowm<=z && z<=obj_z_highm)
        {
            TH = atan2(y-y_centre,x-x_centre);
            
            TH = TH * (180/PI);
            
            //TH = TH % 360;
            TH=fmod(TH, 360);
            
            if (TH<0){
                TH=TH+360;                
            }
            
            obj_a_startm = a_start - margin_z;
            obj_a_stopm  = a_stop  + margin_z;
            
            if (obj_a_startm<0){
                if (TH>=360+obj_a_startm){                    
                    TH=TH-360;}                                 
            }
                if (TH >= obj_a_startm && TH <=obj_a_stopm){

                    stts[0]=1;
                    return;
                }
                else 
                {       stts[0]=0;
                        return;
                }
            
        }
        else {stts[0]=0;return;}        
    }
    else{stts[0]=0;return;}                
}
   